============
Contributing
============

Code is hosted at `opendev.org`_. Submit bugs to the searchlight project
on `Storyboard`_. Submit code to the openstack/python-searchlightclient project
using `Gerrit`_.

.. _opendev.org: https://opendev.org/openstack/python-searchlightclient
.. _Storyboard: https://storyboard.openstack.org/#!/project_group/93
.. _Gerrit: https://docs.openstack.org/infra/manual/developers.html#development-workflow

Testing
-------

The preferred way to run the unit tests is using ``tox``.

See `Consistent Testing Interface`_ for more details.

.. _Consistent Testing Interface: https://opendev.org/openstack/governance/tree/reference/project-testing-interface.rst
